      SUBROUTINE f7arg(narg, args, flgs, iarg, arg, istat)
c
c Return the value of a specified stand-alone argument or the number of
c stand-alone arguments.
c
c File f7arg.f (Version 1.1).  Last modified 17:35:36, 6/7/95.
c
c.......................................................................
c
c From:  National Simulation Resource 
c        Center for Bioengineering
c        University of Washington
c        Box 357962
c        Seattle, WA 98195-7962
c
c        Dr. J. B. Bassingthwaighte, Director
c
c.......................................................................
c
c Copyright (C) 1995 by National Simulation Resource, Univ of WA.
c All Rights Reserved.
c 
c Software may be copied so long as this copyright notice is included.
c This software was developed with support from NIH grant RR-01243.
c Please cite this grant in any publication for which this software
c is used and send one reprint to the address given above.
c
c.......................................................................
c
c SYNOPSIS:
c
c     SUBROUTINE f7arg(narg, args, flgs, iarg, arg, istat)
c
c     CHARACTER*(*) args(*), flgs(*), arg
c     INTEGER       narg, iarg, istat
c     
c.......................................................................
c
c DESCRIPTION:
c
c This subroutine returns the value of a specified stand-alone argument.
c A stand-alone argument does not have an associated flag (i.e., the
c value of the corresponding flgs is 'NONE').
c
c f7arg can also return the total number of stand-alone arguments.
c 
c.......................................................................
c
c FORMAL PARAMETERS:
c
c INPUTS:
c
c    Name   Description
c    ------ ------------------------------------------------------------
c    narg   The number of flags/arguments (i.e., the number of elements
c           in args and flgs).
c    args   A character array of arguments. (Filled by f7args)
c    flgs   A character array of flags. (Filled by f7args)
c    iarg   The number of the desired stand-alone argument.  Note that
c           if iarg=0, it is also an output.
c
c OUTPUTS:
c
c    Name   Description
c    ------ ------------------------------------------------------------
c    iarg   If iarg=0 on entry, iarg is set to the total number of
c           stand-alone arguments on return.
c    arg    The argument value or blanks if iarg=0 on entry.
c    istat  Return status. (See DIAGNOSTICS)
c
c.......................................................................
c
c LIMITATIONS/WARNINGS: None
c
c.......................................................................
c
c DIAGNOSTICS:
c
c The return status is given by istat.  Values are:
c      0 - Normal return.
c     -1 - Error return (argument not found).
c    -99 - Error return (length of argument exceeds length of arg).
c           
c.......................................................................
c
c EXAMPLES:
c
c Given the following arrays:
c
c   I  ARGS(I)    FLGS(I)
c   -  -------    -------
c   1   arg1       flg1
c   2   arg2       flg2
c   3   arg3      'NONE'
c   4   arg4       flg4
c   5   arg5      'NONE'
c   6   arg6      'NONE'
c
c Calling f7arg with iarg=0 returns iarg=3, arg=' ', and istat=0. A call
c with iarg=2 returns arg='arg5', and istat=0, and iarg=4 returns
c istat=-1.
c
c.......................................................................
c
c SUBROUTINES/FUNCTIONS CALLED:
c
c NSR combined library:
c      f7case: Return the upper case version of a string.
c
c FORTRAN intrinsic:
c         len: Get the length of a string.
c      lnblnk: Find the last non-blank character in a string.
c
c.......................................................................
c
c SEE ALSO:
c
c   f7args(3) - Get command-line arguments & fill arrays args and flgs.
c   f7flag(3) - Get the value of an argument associated with a flag.
c
c.......................................................................
c FILES:
c
c /usr/local/lib/libnsr.a      - library archive
c ~libnsr/lib/libmachdep/f7arg - source files
c
c.......................................................................
c
c AUTHOR:
c
c National Simulation Resource 
c Center for Bioengineering
c University of Washington
c Box 357962
c Seattle, WA 98195-7962
c
c.......................................................................
c
c FOR ASSISTANCE:
c
c Questions regarding this software can be sent by electronic mail to:
c   librarian@nsr.bioeng.washington.edu
c
c.......................................................................
c
c HISTORY:
c
c Written:  R. B. King (MAR95)
c
c Modified:
c Ver. N.N: Description (AUTHOR - DATE)
c
c-----------------------------------------------------------------------
c
      CHARACTER*(*) args(*), flgs(*), arg
      INTEGER       narg, iarg, istat
c
      CHARACTER*4   f7case
      CHARACTER*63  sid1, sid2
      INTEGER       i, inx, lnblnk, len
c
      EXTERNAL      f7case
c
      DATA         sid1
     + /'@(#)f7arg.f	1.1 created on 6/7/95 at 17:35:36.'/
      DATA         sid2
     + /'@(#)    Retrieved on 10/21/96 at 14:14:02.'/
c
c Initialize local variables.
c
      inx = 0
c
c Assume failure.
c
      istat = -1
      arg   = ' '
c
c Handle the request.
c
      IF (iarg .EQ. 0) THEN
c
c         The count of stand-alone arguments is wanted.
c
          DO 1 i = 1, narg
              IF (f7case(flgs(i)) .EQ. 'NONE') iarg = iarg + 1
    1     CONTINUE
c
          istat = 0
          arg   = ' '
c
      ELSE
c
c         A stand-alone argument is wanted.
c
c         Search the argument arrays.
c
          DO 2 i = 1, narg
              IF (f7case(flgs(i)) .EQ. 'NONE') THEN
c
c                 A stand-alone argument has been found.
c
                  inx = inx + 1
                  IF (inx .EQ. iarg) THEN
c
c                     The correct stand-alone argument has been found.
c
                      IF (LEN(arg) .GE. LNBLNK(args(i))) THEN
                          istat = 0
                          arg   = args(i)
                      ELSE
                          istat = -99
                      END IF
                      RETURN
                  END IF
              END IF
    2     CONTINUE
c
      END IF
c
      RETURN
      END
