      SUBROUTINE f7argv(iarg, argv)
c
c Get the value of a command-line argument.
c
c File f7argv.F (Version 1.1).  Last modified 17:55:54, 6/7/95.
c
c.......................................................................
c
c From:  National Simulation Resource 
c        Center for Bioengineering
c        University of Washington
c        Box 357962
c        Seattle, WA 98195-7962
c
c        Dr. J. B. Bassingthwaighte, Director
c
c.......................................................................
c
c Copyright (C) 1995 by National Simulation Resource, Univ of WA.
c All Rights Reserved.
c 
c Software may be copied so long as this copyright notice is included.
c This software was developed with support from NIH grant RR-01243.
c Please cite this grant in any publication for which this software
c is used and send one reprint to the address given above.
c
c.......................................................................
c
c SYNOPSIS:
c
c     SUBROUTINE f7argv(iarg, argv)
c
c     INTEGER       iarg
c     CHARACTER*(*) argv
c
c.......................................................................
c
c DESCRIPTION:
c
c f7argv puts the iarg-thP command-line argument into argv.
c Note that the 0-th argument is the command name.
c 
c.......................................................................
c
c FORMAL PARAMETERS:
c
c INPUTS:
c    Name   Description
c    ------ ------------------------------------------------------------
c    iarg   The index of the argument.
c
c OUTPUTS:
c    Name   Description
c    ------ ------------------------------------------------------------
c    argv   The value of the iarg-th argument.
c
c.......................................................................
c
c LIMITATIONS/WARNINGS:
c
c If the number of characters in the argument is less that the size of
c argv, argv will be blank padded.  If the argument is longer than argv,
c it will be truncated.  If iarg is out of bounds (i.e. greater than the
c actual number of arguments on the command line or a negative number),
c argv will be set to blanks.  While this behavior may not be considered
c optimal, it is set by the behavior of the getarg routine on Sun
c workstations
c
c f7argv is a system dependent routine that needs to be modified
c for various software platforms.
c
c.......................................................................
c
c DIAGNOSTICS: NONE
c
c.......................................................................
c
c EXAMPLES:
c
c Given that argv has a length of 12 and the command line:
c
c    simnlist -n model.names -v model.values model.nicelist
c
c f7argv would give the results:
c
c    iarg argv
c    ---- --------------
c     -1  '            '
c      0  'simnlist    '
c      1  '-n          '
c      2  'model.names '
c      3  '-v          '
c      4  'model.values'
c      5  'model.niceli'
c      6  '            '
c
c.......................................................................
c
c SUBROUTINES/FUNCTIONS CALLED:
c
c Since this is a system dependent function, it may call different
c system library routines on various platforms.
c    - Sun version calls getarg.
c
c.......................................................................
c
c SEE ALSO:
c
c f7argc(3)
c
c.......................................................................
c
c FILES:
c
c /usr/local/lib/libnsr.a       - library archive
c ~libnsr/lib/libmachdep/f7argv - source files
c
c.......................................................................
c
c AUTHOR:
c
c National Simulation Resource 
c Center for Bioengineering
c University of Washington
c Box 357962
c Seattle, WA 98195-7962
c
c.......................................................................
c
c FOR ASSISTANCE:
c
c Questions regarding this software can be sent by electronic mail to:
c   librarian@nsr.bioeng.washington.edu
c
c.......................................................................
c
c HISTORY:
c
c Written:  R. B. King (MAR95)
c
c Modified:
c Ver. N.N: Description (AUTHOR - DATE)
c
c-----------------------------------------------------------------------
c
      INTEGER       iarg
      CHARACTER*(*) argv
c
      CHARACTER*63  sid1, sid2
c
      DATA         sid1
     + /'@(#)f7argv.F	1.1 created on 6/7/95 at 17:55:54.'/
      DATA         sid2
     + /'@(#)    Retrieved on 10/21/96 at 14:14:04.'/
c
      CALL getarg(iarg, argv)
      RETURN
      END
