      SUBROUTINE f7clos(lu, status, ier)
c
c Machine-dependent front end for Fortran CLOSE.
c *** This version for Berkeley portable f77 ***
c
c From:   National Simulation Resource Facility
c         Center for Bioengineering (WD-12)
c         University of Washington
c         Seattle, WA  98195
c
c         Dr. J. Bassingthwaighte, Director
c
c
c Copyright (C) 1989, 1990 by National Simulation Resource
c Facility, Univ of WA. All Rights Reserved.
c Software may be copied so long as this copyright notice is included.
c
c This software was developed with support from NIH grant RR-01243.
c Please cite this grant in any publication for which this software
c is used and send one reprint to the address given above.
c
c
c DESCRIPTION:
c
c     This routine provides a machine-dependent front-end to the
c     Fortran77 CLOSE statement. It is intended to accompany the
c     routine f7open.  It may have to be customized for each system.
c
c CALL AND PARAMETER TYPES:
c
c     INTEGER lu, ier
c     CHARACTER*(*) status
c     CALL f7clos(lu, status, ier)
c
c INPUTS:
c
c     lu     = logical unit number. It is an error if lu is not
c              attached to an open file. lu need not have been opened
c              by f7open in this implementation.
c
c     status = approximately equivalent to the STATUS field of the
c              CLOSE statement. Upper, lower, or mixed case may be
c              used, but only the first 3 characters are examined.
c                 'DEL'  the file is to be deleted.
c                 'KEE'  the file is to be saved.
c                 'SAV' and '   '  are equivalent to 'KEE'.
c              Anything else is an error and no action is taken.
c
c OUTPUTS:
c
c     ier    = returns error flag: 0 = no error; -1 = an error.
c
c SUBROUTINES CALLED:
c
c       f7case    convert a string to upper case
c
c HISTORY:
c
c     Written:
c         12/04/89       L. Weissman
c
c -----------------------------------------------------------------
c
      INTEGER  lu, ier
      CHARACTER*(*) status
c
c  Local variables
c
      INTEGER      NSTAT
      PARAMETER   (NSTAT=4)
      INTEGER      kstat
      CHARACTER*3  f7case, s, sstat(NSTAT)
      EXTERNAL     f7case
      LOGICAL      isopen
      CHARACTER*64 sid1,sid2
c
c  Source control code strings
c
      DATA sid1/'@(#)f7clos.F	1.1 created 1/22/90 16:01:22.'/
      DATA sid2/'@(#) retrieved 10/21/96 14:14:00.'/
c
c  Local DATA
c
      DATA sstat/'DEL','KEE','SAV',' '/
c
c  I. Check and decode parameters
c
      ier = -1
      INQUIRE(lu,OPENED=isopen)
      IF(.NOT. isopen)RETURN
c
      s = f7case(status)
      DO 10 kstat=1,NSTAT
          IF(s .EQ. sstat(kstat))GO TO 20
   10 CONTINUE
      RETURN
c
c  II. Close the file
c
   20 IF(kstat .EQ. 1)THEN
          CLOSE(lu,STATUS='delete',ERR=100)
      ELSE
          CLOSE(lu,ERR=100)
      ENDIF
c
c  III. Normal and abnormal returns
c
      ier = 0
  100 RETURN
      END
