      SUBROUTINE f7flag(narg, args, flgs, flg, arg, istat)
c
c Return the argument associated with a flag.
c
c File f7flag.f (Version 1.1).  Last modified 17:58:45, 6/7/95.
c
c.......................................................................
c
c From:  National Simulation Resource 
c        Center for Bioengineering
c        University of Washington
c        Box 357962
c        Seattle, WA 98195-7962
c
c        Dr. J. B. Bassingthwaighte, Director
c
c.......................................................................
c
c Copyright (C) 1995 by National Simulation Resource, Univ of WA.
c All Rights Reserved.
c 
c Software may be copied so long as this copyright notice is included.
c This software was developed with support from NIH grant RR-01243.
c Please cite this grant in any publication for which this software
c is used and send one reprint to the address given above.
c
c.......................................................................
c
c SYNOPSIS:
c
c     SUBROUTINE f7flag(narg, args, flgs, flg, arg, istat)
c
c     CHARACTER*(*) args(*), flgs(*), arg, flg
c     INTEGER       narg, istat
c
c.......................................................................
c
c DESCRIPTION:
c
c f7flag returns the argument associated with a flag.  The name of the
c flag is specified in flg and the argument is returned in arg. narg and
c arrays args and flgs are filled by f7args.
c 
c.......................................................................
c
c FORMAL PARAMETERS:
c
c  INPUTS:
c    Name   Description
c    ------ ------------------------------------------------------------
c    narg   The number of elements in args and flgs.  Filled by f7args.
c    args   The character vector of arguments.  Filled by f7args.
c    flgs   The character vector of flags.  Filled by f7args.
c    flg    The name of the flag for which the argument is desired.
c
c OUTPUTS:
c    Name   Description
c    ------ ------------------------------------------------------------
c    arg    The argument for flg.
c    istat  Return status. See DIAGNOSTICS.
c           
c.......................................................................
c
c LIMITATIONS/WARNINGS:
c
c flg and flgs are case sensitive.
c
c The length of arg should be equal the length of the strings in args.
c
c Calling f7flag with flg='none' will always return istat = -1.  Use
c f7arg to get the value of a stand-alone argument.
c
c.......................................................................
c
c DIAGNOSTICS:
c
c Return status istat can have the values:
c      0 - Normal return.
c     -1 - Flag not found.
c     -2 - Number of characters in the argument exceeds the length
c          of arg.
c
c If istat is negative, arg is set to a blank string.
c
c.......................................................................
c
c EXAMPLES:
c
c Given narg=5 and the arrays:
c
c         i   flgs(i)    args(i)
c        ---  ------- -------------
c         1    '-a'    'NONE'
c         2    '-c'    'abc'
c         3    'NONE'  'file_name'
c
c Calling f7flag with flg='-c' would return arg='abc' and istat=0.
c flg='-C' would return istat=-1 and arg would be blanks.
c
c.......................................................................
c
c SUBROUTINES/FUNCTIONS CALLED:
c NSR combined library:
c     f7case: Return the upper case equivalent of a string
c
c FORTRAN LIBRARIES:
c     LEN    (Intrinsic)
c     LNBLNK (May be from NSR combined library on some systems.)
c
c.......................................................................
c
c SEE ALSO:
c
c f7args(3), f7arg(3)
c
c.......................................................................
c
c FILES:
c
c /usr/local/lib/libnsr.a       - library archive
c ~libnsr/lib/libmachdep/f7flag - source files
c
c.......................................................................
c
c AUTHOR:
c
c National Simulation Resource 
c Center for Bioengineering
c University of Washington
c Box 357962
c Seattle, WA 98195-7962
c
c.......................................................................
c
c FOR ASSISTANCE:
c
c Questions regarding this software can be sent by electronic mail to:
c   librarian@nsr.bioeng.washington.edu
c
c.......................................................................
c
c HISTORY:
c
c Written:  R. B. King (MAR95)
c
c Modified:
c Ver. N.N: Description (AUTHOR - DATE)
c
c-----------------------------------------------------------------------
c
      CHARACTER*(*)   args(*), flgs(*), arg, flg
      INTEGER         narg, istat
c
c
      INTEGER         i, LEN, LNBLNK
      CHARACTER*128   f7case
      CHARACTER*63    sid1, sid2
c
      DATA            sid1
     + /'@(#)f7flag.f	1.1 created on 6/7/95 at 17:58:45.'/
      DATA            sid2
     + /'@(#)    Retrieved on 10/21/96 at 14:14:03.'/
c
c Assume failure.
c
      istat = -1
      arg   = ' '
c
c Don't accept a flag of 'none'.
c
      IF (f7case(flg) .EQ. 'NONE') RETURN
c
c Search for the flag.
c
      DO 1 i = 1, narg
          IF (flg .EQ. flgs(i)) GO TO 99
    1 CONTINUE
      RETURN
c
c Flag was found.
c
   99 IF (LEN(arg) .LT. LNBLNK(args(i))) THEN
c
c         Length of argument exceeds length of arg.
c
          istat = -2
      ELSE
c
c         Success.
c
          istat = 0
          arg   = args(i)
      END IF
      RETURN
c
      END
