      SUBROUTINE f7init
c
c System-specific Fortran initialization.
c
c File f7init.F (Version 1.5).  Last modified at 11:26:56 on 1/23/95.
c
c.......................................................................
c
c From:  National Simulation Resource
c        Center for Bioengineering WD-12
c        University of Washington
c        Seattle, WA 98195
c
c        Dr. J. B. Bassingthwaighte, Director
c
c Copyright (C) 1989-1995 by
c National Simulation Resource, Univ of WA. All Rights Reserved.
c Software may be copied so long as this copyright notice is included.
c 
c This software was developed with support from NIH grant RR-01243.
c Please cite this grant in any publication for which this software
c is used and send one reprint to the address given above.
c
c.......................................................................
c
c DESCRIPTION:
c  This routine should is called early in Fortran programs to handle
c  system-specific initialization. Just about any kind of system-
c  specific code might appear in this module.
c
c CALL AND PARAMETER TYPES:
c     CALL f7init
c
c.......................................................................
c
c HISTORY:
c Written: 22-Jan-91  L. Weissman
c
c Modified:
c 16-Mar-92 LW Fortran 1.4 version
c 16-Mar-92 LW Add ieee_retrospective() to get rid of diagnostics
c Ver. 1.3: Added sgi and dec_mips versions. (NOV93 - R.B. King)
c Ver. 1.4: Fixed some comment lines. (AUG94 - Unknown)
c Ver. 1.4: Added SGI support to abort on serious errors.  Cleaned up
c           comments and style.  (DEC94 - L.J. Weissman, R.B. King)
c
c-----------------------------------------------------------------------
c
#if sun
c
c SPARC version
c
c  On Sun SPARC systems, the only thing we need is to set up floating
c  point (FP) behavior to mimic conventional FP hardware typical of the
c  1970s and 1980s, rather than IEEE default floating point behavior.
c  In particular:
c     1) Serious errors (overflow, zero-divide, invalid function
c        arguments) must cause an immediate abort. IEEE default behavior
c        is to forge ahead with a NaN or Inf.
c     2) Underflows should be set silently to zero. IEEE default
c        behavior requires soft underflow, which on SPARC systems is
c        handled in software and requires about 20x the execution time.
c     3) Minor errors (underflow, imprecise) should not be tallied or
c        reported upon program termination.
c  This routine may be called more than once, but DO NOT call the
c  handler routine fperr() directly.
c
c LIMITATIONS:
c  This routine is specific to Sun workstations running Fortran version
c  1.2 or higher. There are slight incompatibilities between 1.2 and
c  1.3/1.4.
c
c REFERENCES:
c  SunOS Numerical Computation Guide.
c  SunOS Fortran Reference Manual.
c
      CHARACTER*4 out
      INTEGER     ieee_handler,ieee_flags
      EXTERNAL    fperr, ieee_handler
c
c Source Code Control Data
c
      CHARACTER*54 sid1, sid2
      DATA sid1 /'@(#)f7init.F	1.5 created 1/23/95 11:26:56.'/
      DATA sid2 /'@(#) retrieved 10/21/96 14:13:58.'/
c
c  Disable gradual underflow, as it takes too long to handle
c  denormalized numbers in software.
c
      CALL abrupt_underflow
c
c  Reset all exception flags
c  Next line causes a seg-err in F77 1.2, but not 1.3 or 1.4. So comment
c  it out in F77 1.2.
c
      i=ieee_flags('clear','exception','all',out)
c
c  Set up error handling. Note that the third argument is explicit
c  because of declaration differences in Fortran 1.2 and 1.3/1.4.
c
c                                                Fortran 1.2 version
c**   i=ieee_handler('set','common',%val(2))
c                                                Fortran 1.3/4 version
      i=ieee_handler('set','common',fperr)
      IF(i .NE. 0) WRITE(0,10)
10    FORMAT(' F7INIT: Handler could not be enabled')
      RETURN
      END
c
c.......................................................................
c
      INTEGER FUNCTION fperr(sig,code,context)
c
c  Floating point error handler. This routine gets called when a serious
c  floating point error has occurred. We attempt to figure out what kind
c  of error occurred, then abort.
c
c LIMITATIONS:
c  This is highly system-dependent. This version for Sun SPARC systems.
c  Do not attempt to call this routine directly.
c
c REFERENCES:
c  See the comments to f7init() for full details.
c
      INTEGER      sig, code, context(5)
      PARAMETER   (NMSG=5)
      CHARACTER*16 errmsg(0:NMSG)
      INTEGER      msgnum(NMSG)
      DATA errmsg/'unknown','invalid','division by zero',
     +   'overflow','underflow','inexact'/
      DATA msgnum/208,200,212,204,196/
c
      j=0
      loccode=loc(code)
      DO 10 i=1,NMSG
          IF(loccode .EQ. msgnum(i)) THEN
              j=i
              GO TO 20
          ENDIF
10    CONTINUE
20    WRITE(0,30) context(4),errmsg(j)
30    FORMAT(' ieee exception at pc=0x',z8.8,': ',a)
      CALL abort
      END
c
c.......................................................................
c
      SUBROUTINE ieee_retrospective(n)
c
c  This function prevents the standard function of the same name from
c  being called after the program has exited.
c  LW 21-May-92
c
      INTEGER n
      RETURN
      END

#elif sgi
c
c-----------------------------------------------------------------------
c
c Silicon Graphics version [LW 14-Dec-94]
c
c See "man fsigfpe" and <fsigfpe.h> below for details.
c Must be linked with libfpe.a.
c
#include <fsigfpe.h>
c
c Set underflow to zero, but serious errors cause an abort.
c Not necessary to replace handlers.
c
      fsigfpe(FPE_UNDERFL).repls = FPE_ZERO
      fsigfpe(FPE_DIVZERO).abort = 1
      fsigfpe(FPE_OVERFL ).abort = 1
      fsigfpe(FPE_INVALID).abort = 1
c
c The stack trace is not always reliable, so disable it for now. Better
c to use dbx on the core file.
c
c     fsigfpe(FPE_DIVZERO).trace = 1
c     fsigfpe(FPE_OVERFL ).trace = 1
c     fsigfpe(FPE_INVALID).trace = 1
c
      CALL handle_sigfpes(FPE_ON,
     +   FPE_EN_UNDERFL + FPE_EN_OVERFL +
     +   FPE_EN_DIVZERO + FPE_EN_INVALID,
     +   0, FPE_ABORT_ON_ERROR, 0)
      RETURN
      END
#else
c
c-----------------------------------------------------------------------
c
c No-op version (Ultrix, OSF/1, Linux until we figure out FPU behavior)
c
      RETURN
      END
#endif
