      REAL FUNCTION r1mach ( i )

c*****************************************************************************80
c Modified January 24, 2011
c Converted back to FORTRAN
c Gary M. Raymond
c
c R1MACH returns single precision real machine constants.
c
c  Discussion:
c
c    Assume that single precision real numbers are stored with a mantissa
c    of T digits in base B, with an exponent whose value must lie
c    between EMIN and EMAX.  Then for values of I between 1 and 5,
c    R1MACH will return the following values:
c
c      R1MACH(1) = B^(EMIN-1), the smallest positive magnitude.
c      R1MACH(2) = B^EMAX*(1-B^(-T)), the largest magnitude.
c      R1MACH(3) = B^(-T), the smallest relative spacing.
c      R1MACH(4) = B^(1-T), the largest relative spacing.
c      R1MACH(5) = log10(B)
c
c  Licensing:
c
c    This code is distributed under the GNU LGPL license.
c
c  Modified:
c
c    24 April 2007
c
c  Author:
c
c    Original FORTRAN77 version by Phyllis Fox, Andrew Hall, Norman Schryer
c    MATLAB version by John Burkardt.
c
c  Reference:
c
c    Phyllis Fox, Andrew Hall, Norman Schryer,
c    Algorithm 528,
c    Framework for a Portable Library,
c    ACM Transactions on Mathematical Software,
c    Volume 4, Number 2, June 1978, page 176-188.
c
c  Parameters:
c
c    Input, integer I, chooses the parameter to be returned.
c    1 <= I <= 5.
c
c    Output, real VALUE, the value of the chosen parameter.
c
c if ( i < 1 )
c   fprintf ( 1, '\n' );
c   fprintf ( 1, 'R1MACH - Fatal error!\n' );
c   fprintf ( 1, '  The input argument I is out of bounds.\n' );
c   fprintf ( 1, '  Legal values satisfy 1 <= I <= 5.\n' );
c   fprintf ( 1, '  I = cd\n', i );
c   value = 0.0;
c   error ( 'R1MACH - Fatal error!' );
c elseif ( i == 1 )
c   value = 1.1754944E-38;
c elseif ( i == 2 )
c   value = 3.4028235E+38;
c elseif ( i == 3 )
c   value = 5.9604645E-08;
c elseif ( i == 4 )
c   value = 1.1920929E-07;
c elseif ( i == 5 )
c   value = 0.3010300;
c elseif ( 5 < i )
c   fprintf ( 1, '\n' );
c   fprintf ( 1, 'R1MACH - Fatal error!\n' );
c   fprintf ( 1, '  The input argument I is out of bounds.\n' );
c   fprintf ( 1, '  Legal values satisfy 1 <= I <= 5.\n' );
c   fprintf ( 1, '  I = cd\n', i );
c   value = 0.0;
c   error ( 'R1MACH - Fatal error!' );
c end
      if(i.LT.1) WRITE(*,*) 'r1mach: argument<1 or >5 ERROR'
      if(i.EQ.1) r1mach = 1.1754944E-38
      if(i.EQ.2) r1mach = 3.4028235E+38
      if(i.EQ.3) r1mach = 5.9604645E-08
      if(i.EQ.4) r1mach = 1.1920929E-07
      if(i.eq.5) r1mach = 0.3010300
      return
      end

