


HURST(1L)                LOCAL COMMANDS                 HURST(1L)



NAME
     hurst - perform HURST rescaled range  (R/S)  analysis  on  a
     fractal time series

SYNOPSIS
     hurst [-c ncol] [-t trend] [-s skip] [input_file_name]

DESCRIPTION
     hurst calculates an estimate of the Hurst coefficient  using
     rescaled  range analysis of the time series contained in the
     input file.  The program creates seven  output  files.   The
     input  file  is  named  on  the command line and is given as
     input_file_name. If  the  input_file_name  is  missing,  the
     input is assumed to come from standard input.

     Let x(j), j=1,2,...n be a series of N points.  Subtract  the
     mean from x so that the new mean is zero.  Over some portion
     of this data from j=i,...i+kmax, define
     VN(i,k,kmax) = sum from j=i to i+k (x(j)),  k=0 to kmax.

     The mean from j=i to i+kmax is given by
     Mean(i,kmax)=VN(i,kmax,kmax)/(kmax+1).

     Define
     VR(i,k,kmax) = sum from j=i to i+k  (  x(j)-Mean(i,kmax)  ),
     k=0 to kmax.

     The difference between the maximum  and  minimum  values  of
     VN(i,k,kmax)  as  k  varies  from  0  to  kmax is the Range,
     R(i,kmax).  The difference between the maximum  and  minimum
     values  of  VR(i,k,kmax)  as k varies from 0 to kmax is also
     known as the Range, R(i,kmax). The range of VR is called the
     trend  corrected  range,  because  VR(i,kmax,kmax)=0.0.  The
     range, R(i,kmax), in either case is normalized by the  stan-
     dard  deviation  of  the data, S, over the same x values. We
     speak of the rescaled range  without  trend  correction,  or
     with trend correction, respectively.

     The Rescaled Range (R/S) is computed for the entire  series.
     The  series  is  then halved. Each halved series has its R/S
     calculated.  If the original series contained an odd  number
     of  points,  the  odd  point is counted in the middle of the
     series and belongs  to  both  half-length  series.  In  this
     fashion  the  series  continues  to  be subdivided until the
     final pieces have at least six points. The rescaled range is
     computed  for  all  pieces  of  the  series. The length (the
     number of points) of each piece is normalized by  the  total
     length of the series.

     The  analysis  proceeds  along  three  separate  paths:  the
     analysis  of  all the data (multipox analysis), the means of
     the  rescaled  ranges  for  each  particular  length   (mean
     analysis),  and a subset of the data (pox analysis). In each
     case the Y-on-X regression is calculated.

     In multipox analysis the regression  is  between  the  loga-
     rithms  of  the normalized lengths and the logarithms of the
     rescaled ranges.
     In mean analysis, the regression is between  the  logarithms
     of the normalized lengths and the logarithms of the means of
     the rescaled ranges for those lengths.

     In pox analysis, the regression is between the logarithms of
     the  normalized  lengths  and the logarithms of a maximum of
     ten values of the rescaled range at each normalized length.
     The slope of these regressions are the estimated Hurst coef-
     ficients.

     The seven output files are named:


     input_file_name.hurst.multipox        Contains 2  columns  of  data.  The
                                           first  column  contains the normal-
                                           ized length, and the second  column
                                           contains the rescaled range (R/S).
     input_file_name.hurst.mean            Contains 6 columns of data.  Column
                                           one  is  the normalized length. For
                                           each length, the subsequent columns
                                           are: column two, the average of the
                                           R/S;  column  three,  the  standard
                                           deviation  of the R/S; column four,
                                           the  standard  error  of  the  R/S;
                                           column  five,  the minimum value of
                                           the R/S; and column six,  the  max-
                                           imum value of the R/S.
     input_file_name.hurst.pox             Contains 2  columns  of  data.  The
                                           first  column  contains the normal-
                                           ized. The  second  column  contains
                                           the  R/S  for that length. For each
                                           length, a maximum of ten values are
                                           used.
     input_file_name.hurst.multipox.line   Contains 2 columns of data  and  is
                                           the  linear  fit  through the loga-
                                           rithms    of    the     data     in
                                           input_file_name.hurst.multipox.
     input_file_name.hurst.mean.line       Contains 2 columns of data  and  is
                                           the  linear  fit  through the loga-
                                           rithms    of    the     data     in
                                           input_file_name.hurst.mean.
     input_file_name.hurst.pox.line        Contains 2 columns of data  and  is
                                           the  linear  fit  through the loga-
                                           rithms    of    the     data     in
                                           input_file_name.hurst.pox.
     input_file_name.hurst.summary.fits    Summarizes  the  analysis  and  the
                                           three fits, and gives the estimated
                                           Hurst  coefficient  for  all  three
                                           methods of analysis.

FLAGS/ARGUMENTS
     -c                Ncol is the   number  of  columns  in  the  output
                       files.  If  the  number of columns is 2, the first
                       column  contains  consecutive  integers,  and  the
                       second  column  contains the data.  The default is
                       1.
     -t                If trend equals r, VR is  used  to  calculate  the
                       range.  If trend equals n, VN is used to calculate
                       the range.  The default is "n".
     -s                Skip is the number of largest bin  sizes  to  skip
                       when  fitting  straight lines to the logarithms of
                       the data in all three analyses. For example, if  a
                       value  of  3  were  to be used, the R/S values for
                       normalized lengths=1.0, 0.5,  and  0.25  would  be
                       omitted  from  the line fitting.  For all the data
                       and the pox analysis this removes  7  values  (one
                       value  for  normalized  lengths =1, two values for
                       length=0.5, and four values for length=0.25).  For
                       the mean data, it would remove 3 values (one value
                       for normalized lengths = 1.0, 0.5, and 0.25).  The
                       reason for removing these values is that they lack
                       statistical significance and tend  to  be  biased.
                       The default is 0.
     input_file_name   If the input file name is missing,  the  input  is
                       read  from  standard  input,   and the output file
                       names will be hurst.multipox, hurst.mean, etc.

EXAMPLE
     A file named "data" contains two columns. The  first  column
     is  time  and  the  second  column is a measured signal. The
     Hurst analysis is to be done without trend removal. All  the
     rescaled  ranges will be used to determine the Hurst coeffi-
     cient. Enter the following command:
     hurst -c 2 -t n -s 0 data
     The summary of the analysis  will  be  found  in  the  file,
     "data.hurst.summary.fits".

WARNINGS
     Maximum  number  of  points  in  a  file  processed   equals
     1,048,576,  excess  points  are  ignored.  Minimum number of
     points in a file is 8.

DIAGNOSTICS
     If the program fails because of improper arguments, a  diag-
     nostic  message indicating the cause of the failure is writ-
     ten to stderr.

REFERENCES
     Evaluating Rescaled Range Analysis  for  Time  Series,  J.B.
     Bassingthwaighte  and  G  M.  Raymond,  Annals of Biomedical
     Engineering, Vol. 22, pp. 432-444, 1994.

SUBROUTINES and/or FUNCTIONS CALLED
     Internal:
     calrsr                   Calculate rescaled range of a series

     NSR Math Library:
     f7args                   Process command line arguments and switches
     f7init                   Initialize FORTRAN program
     f7open                   Open FORTRAN sequential files
     f7clos                   Close FORTRAN sequential files
     f7exit                   Exit FORTRAN program
     linreg                   Weighted geometric mean linear regression

     Combined Math Library:
     r1mach                   Machine dependent constants

SEE ALSO
     disp(1), sra(1), ssm(1)

FILES
     ~libnsr/prog/fractal/hurst - Source directory

AUTHOR
     National Simulation Resource
     Center for Bioengineering (WD-12)
     University of Washington
     Seattle, WA 98195

FOR ASSISTANCE
     Questions regarding this software can be sent by  electronic
     mail to:
             librarian@nsr.bioeng.washington.edu
